#ifndef _L3D_H
#define _L3D_H

#include "application.h"
#include "neopixel.h"

#if defined(PLATFORM_ID)
#if (PLATFORM_ID == 0) // Core
#define PROCESSOR "core"
#elif (PLATFORM_ID == 6) // Photon
#define PROCESSOR "photon"
#else
#define PROCESSOR "unknown"
#endif
#else
#define PROCESSOR "core"
#endif

#define PIXEL_COUNT 512
#define PIXEL_PIN D0
#define PIXEL_TYPE WS2812B

#define INTERNET_BUTTON D2
#define MODE D3

#define STREAMING_PORT 2222

#define MICROPHONE 12
#define X 13
#define Y 14
#define Z 15

/**   Definitions for Text. */
#include <string>
#define FONT_TBL_SIZE   4736
typedef unsigned char byte;

/**   An RGB color. */
struct Color
{
  unsigned char red, green, blue;

  Color(int r, int g, int b) : red(r), green(g), blue(b) {}
  Color() : red(0), green(0), blue(0) {}
};

/**   A point in 3D space.  */
struct Point
{
  float x;
  float y;
  float z;
  Point() : x(0), y(0), z(0) {}
  Point(float _x, float _y, float _z) : x(_x), y(_y), z(_z) {}
};

/** Overloaded != operator. */
bool operator!= (const Color& a, const Color& b);

/** Overloaded == operator. */
bool operator== (const Color& a, const Color& b);

/**   An L3D LED cube.
      Provides methods for drawing in 3D. Controls the LED hardware.
*/
class Cube
{
  private:
    bool onlinePressed;
    bool lastOnline;
    Adafruit_NeoPixel strip;
    UDP udp;
    int lastUpdated;
    char localIP[24];
    char macAddress[20];
    int port;
	
	// Text members
	byte font[FONT_TBL_SIZE] =
	{
		// tinytype.pf  
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 000 (.)
		(byte)0x7E, (byte)0x81, (byte)0xA5, (byte)0x81, (byte)0xA5, (byte)0x99, (byte)0x81, (byte)0x7E, // Char 001 (.)
		(byte)0x3C, (byte)0x7E, (byte)0xDB, (byte)0xFF, (byte)0xC3, (byte)0x7E, (byte)0x3C, (byte)0x00, // Char 002 (.)
		(byte)0x00, (byte)0x6C, (byte)0xFE, (byte)0xFE, (byte)0x7C, (byte)0x38, (byte)0x10, (byte)0x00, // Char 003 (.)
		(byte)0x10, (byte)0x38, (byte)0x7C, (byte)0xFE, (byte)0x7C, (byte)0x38, (byte)0x10, (byte)0x00, // Char 004 (.)
		(byte)0x00, (byte)0x3C, (byte)0x18, (byte)0xFF, (byte)0xFF, (byte)0x08, (byte)0x18, (byte)0x00, // Char 005 (.)
		(byte)0x10, (byte)0x38, (byte)0x7C, (byte)0xFE, (byte)0xFE, (byte)0x10, (byte)0x38, (byte)0x00, // Char 006 (.)
		(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3C, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, // Char 007 (.)
		(byte)0xFF, (byte)0xFF, (byte)0xE7, (byte)0xC3, (byte)0xE7, (byte)0xFF, (byte)0xFF, (byte)0xFF, // Char 008 (.)
		(byte)0x00, (byte)0x3C, (byte)0x42, (byte)0x81, (byte)0x81, (byte)0x42, (byte)0x3C, (byte)0x00, // Char 009 (.)
		(byte)0xFF, (byte)0xC3, (byte)0xBD, (byte)0x7E, (byte)0x7E, (byte)0xBD, (byte)0xC3, (byte)0xFF, // Char 010 (.)
		(byte)0x1F, (byte)0x07, (byte)0x0D, (byte)0x7C, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 011 (.)
		(byte)0x00, (byte)0x7E, (byte)0xC3, (byte)0xC3, (byte)0x7E, (byte)0x18, (byte)0x7E, (byte)0x18, // Char 012 (.)
		(byte)0x04, (byte)0x06, (byte)0x07, (byte)0x04, (byte)0x04, (byte)0xFC, (byte)0xF8, (byte)0x00, // Char 013 (.)
		(byte)0x0C, (byte)0x0A, (byte)0x0D, (byte)0x0B, (byte)0xF9, (byte)0xF9, (byte)0x1F, (byte)0x1F, // Char 014 (.)
		(byte)0x00, (byte)0x92, (byte)0x7C, (byte)0x6C, (byte)0xC6, (byte)0x6C, (byte)0x7C, (byte)0x92, // Char 015 (.)
		(byte)0x00, (byte)0x00, (byte)0x60, (byte)0x78, (byte)0x7E, (byte)0x78, (byte)0x60, (byte)0x00, // Char 016 (.)
		(byte)0x00, (byte)0x00, (byte)0x06, (byte)0x1E, (byte)0x7E, (byte)0x1E, (byte)0x06, (byte)0x00, // Char 017 (.)
		(byte)0x18, (byte)0x7E, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x7E, (byte)0x18, // Char 018 (.)
		(byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x00, (byte)0x24, (byte)0x00, // Char 019 (.)
		(byte)0xFF, (byte)0xB6, (byte)0x76, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x00, // Char 020 (.)
		(byte)0x7E, (byte)0xC1, (byte)0xDC, (byte)0x22, (byte)0x22, (byte)0x1F, (byte)0x83, (byte)0x7E, // Char 021 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7E, (byte)0x7E, (byte)0x00, (byte)0x00, (byte)0x00, // Char 022 (.)
		(byte)0x18, (byte)0x7E, (byte)0x18, (byte)0x18, (byte)0x7E, (byte)0x18, (byte)0x00, (byte)0xFF, // Char 023 (.)
		(byte)0x08, (byte)0x1C, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x00, // Char 024 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x1C, (byte)0x08, (byte)0x00, // Char 025 (.)
		(byte)0x00, (byte)0x00, (byte)0x02, (byte)0xFF, (byte)0x02, (byte)0x00, (byte)0x00, (byte)0x00, // Char 026 (.)
		(byte)0x00, (byte)0x00, (byte)0x40, (byte)0xFF, (byte)0x40, (byte)0x00, (byte)0x00, (byte)0x00, // Char 027 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xC0, (byte)0xC0, (byte)0xC0, (byte)0xFF, (byte)0x00, // Char 028 (.)
		(byte)0x00, (byte)0x24, (byte)0x66, (byte)0xFF, (byte)0x66, (byte)0x24, (byte)0x00, (byte)0x00, // Char 029 (.)
		(byte)0x00, (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x7C, (byte)0xFE, (byte)0x00, (byte)0x00, // Char 030 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFE, (byte)0x7C, (byte)0x38, (byte)0x10, (byte)0x00, // Char 031 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 032 ( )
		(byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x00, (byte)0x10, (byte)0x00, // Char 033 (!)
		(byte)0x44, (byte)0x22, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 034 (")
		(byte)0x28, (byte)0x28, (byte)0xFE, (byte)0x28, (byte)0xFE, (byte)0x28, (byte)0x28, (byte)0x00, // Char 035 (#)
		(byte)0x28, (byte)0x7C, (byte)0xA8, (byte)0x7C, (byte)0x2A, (byte)0x7C, (byte)0x28, (byte)0x00, // Char 036 ($)
		(byte)0x60, (byte)0x94, (byte)0x68, (byte)0x10, (byte)0x2C, (byte)0x52, (byte)0x8C, (byte)0x00, // Char 037 (%)
		(byte)0x30, (byte)0x48, (byte)0x30, (byte)0x48, (byte)0x86, (byte)0x84, (byte)0x78, (byte)0x00, // Char 038 (&)
		(byte)0x04, (byte)0x04, (byte)0x08, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 039 (')
		(byte)0x10, (byte)0x20, (byte)0x40, (byte)0x40, (byte)0x40, (byte)0x20, (byte)0x10, (byte)0x00, // Char 040 (()
		(byte)0x10, (byte)0x08, (byte)0x04, (byte)0x04, (byte)0x04, (byte)0x08, (byte)0x10, (byte)0x00, // Char 041 ())
		(byte)0x00, (byte)0x54, (byte)0x38, (byte)0x7C, (byte)0x38, (byte)0x54, (byte)0x00, (byte)0x00, // Char 042 (*)
		(byte)0x00, (byte)0x08, (byte)0x08, (byte)0x3E, (byte)0x08, (byte)0x08, (byte)0x00, (byte)0x00, // Char 043 (+)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x08, (byte)0x10, // Char 044 (,)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7E, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 045 (-)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x08, (byte)0x00, // Char 046 (.)
		(byte)0x02, (byte)0x04, (byte)0x08, (byte)0x10, (byte)0x20, (byte)0x40, (byte)0x80, (byte)0x00, // Char 047 (/)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x2C, (byte)0x34, (byte)0x24, (byte)0x18, (byte)0x00, // Char 048 (0)
		(byte)0x00, (byte)0x10, (byte)0x30, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x38, (byte)0x00, // Char 049 (1)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x04, (byte)0x18, (byte)0x20, (byte)0x3C, (byte)0x00, // Char 050 (2)
		(byte)0x00, (byte)0x38, (byte)0x04, (byte)0x18, (byte)0x04, (byte)0x04, (byte)0x38, (byte)0x00, // Char 051 (3)
		(byte)0x00, (byte)0x20, (byte)0x28, (byte)0x28, (byte)0x3C, (byte)0x08, (byte)0x08, (byte)0x00, // Char 052 (4)
		(byte)0x00, (byte)0x3C, (byte)0x20, (byte)0x38, (byte)0x04, (byte)0x04, (byte)0x38, (byte)0x00, // Char 053 (5)
		(byte)0x00, (byte)0x1C, (byte)0x20, (byte)0x38, (byte)0x24, (byte)0x24, (byte)0x18, (byte)0x00, // Char 054 (6)
		(byte)0x00, (byte)0x3C, (byte)0x04, (byte)0x08, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x00, // Char 055 (7)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x18, (byte)0x00, // Char 056 (8)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x1C, (byte)0x04, (byte)0x38, (byte)0x00, // Char 057 (9)
		(byte)0x00, (byte)0x10, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x00, (byte)0x00, // Char 058 (:)
		(byte)0x00, (byte)0x10, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x20, (byte)0x00, // Char 059 (;)
		(byte)0x00, (byte)0x08, (byte)0x10, (byte)0x20, (byte)0x10, (byte)0x08, (byte)0x00, (byte)0x00, // Char 060 (<)
		(byte)0x00, (byte)0x00, (byte)0x7E, (byte)0x00, (byte)0x7E, (byte)0x00, (byte)0x00, (byte)0x00, // Char 061 (=)
		(byte)0x00, (byte)0x20, (byte)0x10, (byte)0x08, (byte)0x10, (byte)0x20, (byte)0x00, (byte)0x00, // Char 062 (>)
		(byte)0x7C, (byte)0x82, (byte)0x04, (byte)0x08, (byte)0x10, (byte)0x00, (byte)0x10, (byte)0x00, // Char 063 (?)
		(byte)0x7C, (byte)0x82, (byte)0x9A, (byte)0xAA, (byte)0xAA, (byte)0x9E, (byte)0x7C, (byte)0x00, // Char 064 (@)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x3C, (byte)0x24, (byte)0x24, (byte)0x00, // Char 065 (A)
		(byte)0x00, (byte)0x38, (byte)0x24, (byte)0x38, (byte)0x24, (byte)0x24, (byte)0x38, (byte)0x00, // Char 066 (B)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x20, (byte)0x20, (byte)0x24, (byte)0x18, (byte)0x00, // Char 067 (C)
		(byte)0x00, (byte)0x38, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x38, (byte)0x00, // Char 068 (D)
		(byte)0x00, (byte)0x3C, (byte)0x20, (byte)0x38, (byte)0x20, (byte)0x20, (byte)0x3C, (byte)0x00, // Char 069 (E)
		(byte)0x00, (byte)0x3C, (byte)0x20, (byte)0x38, (byte)0x20, (byte)0x20, (byte)0x20, (byte)0x00, // Char 070 (F)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x20, (byte)0x2C, (byte)0x24, (byte)0x18, (byte)0x00, // Char 071 (G)
		(byte)0x00, (byte)0x24, (byte)0x24, (byte)0x3C, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x00, // Char 072 (H)
		(byte)0x00, (byte)0x38, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x38, (byte)0x00, // Char 073 (I)
		(byte)0x00, (byte)0x04, (byte)0x04, (byte)0x04, (byte)0x04, (byte)0x24, (byte)0x18, (byte)0x00, // Char 074 (J)
		(byte)0x00, (byte)0x28, (byte)0x28, (byte)0x30, (byte)0x28, (byte)0x24, (byte)0x24, (byte)0x00, // Char 075 (K)
		(byte)0x00, (byte)0x20, (byte)0x20, (byte)0x20, (byte)0x20, (byte)0x20, (byte)0x3C, (byte)0x00, // Char 076 (L)
		(byte)0x00, (byte)0x44, (byte)0x6C, (byte)0x54, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x00, // Char 077 (M)
		(byte)0x00, (byte)0x24, (byte)0x34, (byte)0x34, (byte)0x2C, (byte)0x2C, (byte)0x24, (byte)0x00, // Char 078 (N)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x18, (byte)0x00, // Char 079 (O)
		(byte)0x00, (byte)0x38, (byte)0x24, (byte)0x24, (byte)0x38, (byte)0x20, (byte)0x20, (byte)0x00, // Char 080 (P)
		(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x1C, (byte)0x02, // Char 081 (Q)
		(byte)0x00, (byte)0x38, (byte)0x24, (byte)0x24, (byte)0x38, (byte)0x24, (byte)0x24, (byte)0x00, // Char 082 (R)
		(byte)0x00, (byte)0x1C, (byte)0x20, (byte)0x18, (byte)0x04, (byte)0x04, (byte)0x38, (byte)0x00, // Char 083 (S)
		(byte)0x00, (byte)0x38, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x00, // Char 084 (T)
		(byte)0x00, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x3C, (byte)0x00, // Char 085 (U)
		(byte)0x00, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x14, (byte)0x0C, (byte)0x00, // Char 086 (V)
		(byte)0x00, (byte)0x44, (byte)0x44, (byte)0x44, (byte)0x54, (byte)0x6C, (byte)0x44, (byte)0x00, // Char 087 (W)
		(byte)0x00, (byte)0x24, (byte)0x24, (byte)0x10, (byte)0x08, (byte)0x24, (byte)0x24, (byte)0x00, // Char 088 (X)
		(byte)0x00, (byte)0x22, (byte)0x22, (byte)0x14, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x00, // Char 089 (Y)
		(byte)0x00, (byte)0x3C, (byte)0x04, (byte)0x08, (byte)0x10, (byte)0x20, (byte)0x3C, (byte)0x00, // Char 090 (Z)
		(byte)0x1C, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x1C, (byte)0x00, // Char 091 ([)
		(byte)0x80, (byte)0x40, (byte)0x20, (byte)0x10, (byte)0x08, (byte)0x04, (byte)0x02, (byte)0x00, // Char 092 (\)
		(byte)0x70, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x70, (byte)0x00, // Char 093 (])
		(byte)0x00, (byte)0x00, (byte)0x10, (byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0x00, (byte)0x00, // Char 094 (^)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, // Char 095 (_)
		(byte)0x10, (byte)0x10, (byte)0x08, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 096 (`)
		(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x24, (byte)0x3C, (byte)0x24, (byte)0x24, (byte)0x00, // Char 097 (a)
		(byte)0x00, (byte)0x00, (byte)0x38, (byte)0x24, (byte)0x38, (byte)0x24, (byte)0x38, (byte)0x00, // Char 098 (b)
		(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x24, (byte)0x20, (byte)0x24, (byte)0x18, (byte)0x00, // Char 099 (c)
		(byte)0x00, (byte)0x00, (byte)0x38, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x38, (byte)0x00, // Char 100 (d)
		(byte)0x00, (byte)0x00, (byte)0x3C, (byte)0x20, (byte)0x38, (byte)0x20, (byte)0x3C, (byte)0x00, // Char 101 (e)
		(byte)0x00, (byte)0x00, (byte)0x3C, (byte)0x20, (byte)0x38, (byte)0x20, (byte)0x20, (byte)0x00, // Char 102 (f)
		(byte)0x00, (byte)0x00, (byte)0x1C, (byte)0x20, (byte)0x2C, (byte)0x24, (byte)0x18, (byte)0x00, // Char 103 (g)
		(byte)0x00, (byte)0x00, (byte)0x24, (byte)0x24, (byte)0x3C, (byte)0x24, (byte)0x24, (byte)0x00, // Char 104 (h)
		(byte)0x00, (byte)0x00, (byte)0x1C, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x1C, (byte)0x00, // Char 105 (i)
		(byte)0x00, (byte)0x00, (byte)0x04, (byte)0x04, (byte)0x04, (byte)0x24, (byte)0x18, (byte)0x00, // Char 106 (j)
		(byte)0x00, (byte)0x00, (byte)0x24, (byte)0x28, (byte)0x30, (byte)0x28, (byte)0x24, (byte)0x00, // Char 107 (k)
		(byte)0x00, (byte)0x00, (byte)0x20, (byte)0x20, (byte)0x20, (byte)0x20, (byte)0x3C, (byte)0x00, // Char 108 (l)
		(byte)0x00, (byte)0x00, (byte)0x42, (byte)0x66, (byte)0x5A, (byte)0x42, (byte)0x42, (byte)0x00, // Char 109 (m)
		(byte)0x00, (byte)0x00, (byte)0x24, (byte)0x34, (byte)0x3C, (byte)0x2C, (byte)0x24, (byte)0x00, // Char 110 (n)
		(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x18, (byte)0x00, // Char 111 (o)
		(byte)0x00, (byte)0x00, (byte)0x38, (byte)0x24, (byte)0x38, (byte)0x20, (byte)0x20, (byte)0x00, // Char 112 (p)
		(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x1C, (byte)0x02, // Char 113 (q)
		(byte)0x00, (byte)0x00, (byte)0x38, (byte)0x24, (byte)0x38, (byte)0x24, (byte)0x24, (byte)0x00, // Char 114 (r)
		(byte)0x00, (byte)0x00, (byte)0x1C, (byte)0x20, (byte)0x18, (byte)0x04, (byte)0x38, (byte)0x00, // Char 115 (s)
		(byte)0x00, (byte)0x00, (byte)0x38, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x00, // Char 116 (t)
		(byte)0x00, (byte)0x00, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x3C, (byte)0x00, // Char 117 (u)
		(byte)0x00, (byte)0x00, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x14, (byte)0x0C, (byte)0x00, // Char 118 (v)
		(byte)0x00, (byte)0x00, (byte)0x42, (byte)0x42, (byte)0x5A, (byte)0x66, (byte)0x42, (byte)0x00, // Char 119 (w)
		(byte)0x00, (byte)0x00, (byte)0x44, (byte)0x28, (byte)0x10, (byte)0x28, (byte)0x44, (byte)0x00, // Char 120 (x)
		(byte)0x00, (byte)0x00, (byte)0x44, (byte)0x28, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x00, // Char 121 (y)
		(byte)0x00, (byte)0x00, (byte)0x7C, (byte)0x08, (byte)0x10, (byte)0x20, (byte)0x7C, (byte)0x00, // Char 122 (z)
		(byte)0x0E, (byte)0x10, (byte)0x10, (byte)0x20, (byte)0x10, (byte)0x10, (byte)0x0E, (byte)0x00, // Char 123 ({)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0x00, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x00, // Char 124 (|)
		(byte)0xE0, (byte)0x10, (byte)0x10, (byte)0x08, (byte)0x10, (byte)0x10, (byte)0xE0, (byte)0x00, // Char 125 (})
		(byte)0x00, (byte)0x00, (byte)0x60, (byte)0x92, (byte)0x0C, (byte)0x00, (byte)0x00, (byte)0x00, // Char 126 (~)
		(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x24, (byte)0x42, (byte)0xFF, (byte)0x00, (byte)0x00, // Char 127 (.)
		(byte)0x7C, (byte)0x82, (byte)0x80, (byte)0x80, (byte)0x82, (byte)0x7C, (byte)0x08, (byte)0x30, // Char 128 (.)
		(byte)0x48, (byte)0x00, (byte)0x84, (byte)0x84, (byte)0x84, (byte)0x84, (byte)0x7C, (byte)0x00, // Char 129 (.)
		(byte)0x0C, (byte)0x10, (byte)0x7C, (byte)0x82, (byte)0xFC, (byte)0x80, (byte)0x7C, (byte)0x00, // Char 130 (.)
		(byte)0x18, (byte)0x24, (byte)0x7C, (byte)0x02, (byte)0x7E, (byte)0x82, (byte)0x7C, (byte)0x00, // Char 131 (.)
		(byte)0x24, (byte)0x00, (byte)0x7C, (byte)0x02, (byte)0x7E, (byte)0x82, (byte)0x7C, (byte)0x00, // Char 132 (.)
		(byte)0x18, (byte)0x04, (byte)0x7C, (byte)0x02, (byte)0x7E, (byte)0x82, (byte)0x7C, (byte)0x00, // Char 133 (.)
		(byte)0x10, (byte)0x00, (byte)0x7C, (byte)0x02, (byte)0x7E, (byte)0x82, (byte)0x7C, (byte)0x00, // Char 134 (.)
		(byte)0x00, (byte)0x00, (byte)0x7C, (byte)0x80, (byte)0x80, (byte)0x7C, (byte)0x08, (byte)0x30, // Char 135 (.)
		(byte)0x18, (byte)0x24, (byte)0x7C, (byte)0x82, (byte)0xFC, (byte)0x80, (byte)0x7C, (byte)0x00, // Char 136 (.)
		(byte)0x24, (byte)0x00, (byte)0x7C, (byte)0x82, (byte)0xFC, (byte)0x80, (byte)0x7C, (byte)0x00, // Char 137 (.)
		(byte)0x30, (byte)0x08, (byte)0x7C, (byte)0x82, (byte)0xFC, (byte)0x80, (byte)0x7C, (byte)0x00, // Char 138 (.)
		(byte)0x24, (byte)0x00, (byte)0x18, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x1C, (byte)0x00, // Char 139 (.)
		(byte)0x18, (byte)0x24, (byte)0x18, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x1C, (byte)0x00, // Char 140 (.)
		(byte)0x18, (byte)0x04, (byte)0x18, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x1C, (byte)0x00, // Char 141 (.)
		(byte)0x24, (byte)0x00, (byte)0x38, (byte)0x44, (byte)0x7C, (byte)0x44, (byte)0x44, (byte)0x00, // Char 142 (.)
		(byte)0x18, (byte)0x00, (byte)0x38, (byte)0x44, (byte)0x7C, (byte)0x44, (byte)0x44, (byte)0x00, // Char 143 (.)
		(byte)0x0C, (byte)0x10, (byte)0xFE, (byte)0x40, (byte)0x78, (byte)0x40, (byte)0xFE, (byte)0x00, // Char 144 (.)
		(byte)0x00, (byte)0x00, (byte)0x7C, (byte)0x1A, (byte)0x7E, (byte)0xD8, (byte)0x7E, (byte)0x00, // Char 145 (.)
		(byte)0x7E, (byte)0xD8, (byte)0xD8, (byte)0xDE, (byte)0xF8, (byte)0xD8, (byte)0xDE, (byte)0x00, // Char 146 (.)
		(byte)0x18, (byte)0x24, (byte)0x7C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 147 (.)
		(byte)0x66, (byte)0x00, (byte)0x7C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 148 (.)
		(byte)0x38, (byte)0x0C, (byte)0x7C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 149 (.)
		(byte)0x18, (byte)0x24, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7E, (byte)0x00, // Char 150 (.)
		(byte)0x38, (byte)0x0C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7E, (byte)0x00, // Char 151 (.)
		(byte)0x66, (byte)0x00, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7E, (byte)0x06, (byte)0x7C, // Char 152 (.)
		(byte)0x66, (byte)0x7C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 153 (.)
		(byte)0xC6, (byte)0x00, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 154 (.)
		(byte)0x18, (byte)0x7C, (byte)0xC6, (byte)0xC0, (byte)0xC6, (byte)0x7C, (byte)0x18, (byte)0x00, // Char 155 (.)
		(byte)0x1E, (byte)0x32, (byte)0x30, (byte)0x78, (byte)0x30, (byte)0x70, (byte)0xFE, (byte)0x00, // Char 156 (.)
		(byte)0x66, (byte)0x3C, (byte)0x18, (byte)0x7E, (byte)0x18, (byte)0x3C, (byte)0x18, (byte)0x00, // Char 157 (.)
		(byte)0xFC, (byte)0xC6, (byte)0xFC, (byte)0xC0, (byte)0xCC, (byte)0xDE, (byte)0xCC, (byte)0x0E, // Char 158 (.)
		(byte)0x00, (byte)0x1C, (byte)0x32, (byte)0x30, (byte)0xFC, (byte)0x30, (byte)0xF0, (byte)0x00, // Char 159 (.)
		(byte)0x0E, (byte)0x18, (byte)0x7C, (byte)0x06, (byte)0x7E, (byte)0xC6, (byte)0x7E, (byte)0x00, // Char 160 (.)
		(byte)0x1A, (byte)0x30, (byte)0x38, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3C, (byte)0x00, // Char 161 (.)
		(byte)0x0E, (byte)0x18, (byte)0x7C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 162 (.)
		(byte)0x0E, (byte)0x18, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7E, (byte)0x00, // Char 163 (.)
		(byte)0x66, (byte)0x98, (byte)0xFC, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x00, // Char 164 (.)
		(byte)0x66, (byte)0x98, (byte)0xE6, (byte)0xF6, (byte)0xDE, (byte)0xCE, (byte)0xC6, (byte)0x00, // Char 165 (.)
		(byte)0x7C, (byte)0x06, (byte)0x7E, (byte)0xC6, (byte)0x7E, (byte)0x00, (byte)0xFE, (byte)0x00, // Char 166 (.)
		(byte)0x7C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, (byte)0xFE, (byte)0x00, // Char 167 (.)
		(byte)0x18, (byte)0x00, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 168 (.)
		(byte)0x00, (byte)0x00, (byte)0xFE, (byte)0xC0, (byte)0xC0, (byte)0xC0, (byte)0xC0, (byte)0x00, // Char 169 (.)
		(byte)0x00, (byte)0x00, (byte)0xFE, (byte)0x06, (byte)0x06, (byte)0x06, (byte)0x06, (byte)0x00, // Char 170 (.)
		(byte)0x80, (byte)0x80, (byte)0x80, (byte)0x9C, (byte)0x02, (byte)0x08, (byte)0x1E, (byte)0x00, // Char 171 (.)
		(byte)0x80, (byte)0x80, (byte)0x80, (byte)0x90, (byte)0x14, (byte)0x1E, (byte)0x04, (byte)0x00, // Char 172 (.)
		(byte)0x10, (byte)0x00, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x00, // Char 173 (.)
		(byte)0x00, (byte)0x22, (byte)0x44, (byte)0x88, (byte)0x44, (byte)0x22, (byte)0x00, (byte)0x00, // Char 174 (.)
		(byte)0x00, (byte)0x88, (byte)0x44, (byte)0x22, (byte)0x44, (byte)0x88, (byte)0x00, (byte)0x00, // Char 175 (.)
		(byte)0xAA, (byte)0xAA, (byte)0xAA, (byte)0xAA, (byte)0xAA, (byte)0xAA, (byte)0xAA, (byte)0xAA, // Char 176 (.)
		(byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, (byte)0x55, // Char 177 (.)
		(byte)0x44, (byte)0x22, (byte)0x44, (byte)0x22, (byte)0x44, (byte)0x22, (byte)0x44, (byte)0x22, // Char 178 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, // Char 179 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0xF8, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, // Char 180 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0xF8, (byte)0x08, (byte)0xF8, (byte)0x08, (byte)0x08, // Char 181 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0xF4, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, // Char 182 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFC, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, // Char 183 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xF8, (byte)0x08, (byte)0xF8, (byte)0x08, (byte)0x08, // Char 184 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0xF4, (byte)0x04, (byte)0xF4, (byte)0x14, (byte)0x14, // Char 185 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, // Char 186 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFC, (byte)0x04, (byte)0xF4, (byte)0x14, (byte)0x14, // Char 187 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0xF4, (byte)0x04, (byte)0xFC, (byte)0x00, (byte)0x00, // Char 188 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0xFC, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 189 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0xF8, (byte)0x08, (byte)0xF8, (byte)0x00, (byte)0x00, // Char 190 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xF8, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, // Char 191 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0x0F, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 192 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 193 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, // Char 194 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0x0F, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, // Char 195 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 196 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0xFF, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, // Char 197 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0x0F, (byte)0x08, (byte)0x0F, (byte)0x08, (byte)0x08, // Char 198 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0x17, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, // Char 199 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0x17, (byte)0x10, (byte)0x1F, (byte)0x00, (byte)0x00, // Char 200 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x1F, (byte)0x10, (byte)0x17, (byte)0x14, (byte)0x14, // Char 201 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0xF7, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0x00, // Char 202 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0xF7, (byte)0x14, (byte)0x14, // Char 203 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0x17, (byte)0x10, (byte)0x17, (byte)0x14, (byte)0x14, // Char 204 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0x00, // Char 205 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0xF7, (byte)0x00, (byte)0xF7, (byte)0x14, (byte)0x14, // Char 206 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0xFF, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0x00, // Char 207 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 208 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0xFF, (byte)0x08, (byte)0x08, // Char 209 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, // Char 210 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0x1F, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 211 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0x0F, (byte)0x08, (byte)0x0F, (byte)0x00, (byte)0x00, // Char 212 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x1F, (byte)0x10, (byte)0x1F, (byte)0x10, (byte)0x10, // Char 213 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x1F, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, // Char 214 (.)
		(byte)0x14, (byte)0x14, (byte)0x14, (byte)0xFF, (byte)0x14, (byte)0x14, (byte)0x14, (byte)0x14, // Char 215 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0xFF, (byte)0x08, (byte)0xFF, (byte)0x08, (byte)0x08, // Char 216 (.)
		(byte)0x08, (byte)0x08, (byte)0x08, (byte)0xF8, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 217 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x0F, (byte)0x08, (byte)0x08, (byte)0x08, (byte)0x08, // Char 218 (.)
		(byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, // Char 219 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, // Char 220 (.)
		(byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, // Char 221 (.)
		(byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, // Char 222 (.)
		(byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 223 (.)
		(byte)0x00, (byte)0x00, (byte)0x77, (byte)0x98, (byte)0x98, (byte)0x77, (byte)0x00, (byte)0x00, // Char 224 (.)
		(byte)0x1C, (byte)0x36, (byte)0x66, (byte)0xFC, (byte)0xC6, (byte)0xC6, (byte)0xFC, (byte)0xC0, // Char 225 (.)
		(byte)0xFE, (byte)0x62, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x00, // Char 226 (.)
		(byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x00, // Char 227 (.)
		(byte)0xFE, (byte)0x62, (byte)0x30, (byte)0x18, (byte)0x30, (byte)0x62, (byte)0xFE, (byte)0x00, // Char 228 (.)
		(byte)0x00, (byte)0x00, (byte)0x3F, (byte)0x66, (byte)0xC6, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 229 (.)
		(byte)0x00, (byte)0x00, (byte)0x33, (byte)0x33, (byte)0x33, (byte)0x3E, (byte)0x30, (byte)0xF0, // Char 230 (.)
		(byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, // Char 231 (.)
		(byte)0x3C, (byte)0x18, (byte)0x3C, (byte)0x66, (byte)0x66, (byte)0x3C, (byte)0x18, (byte)0x3C, // Char 232 (.)
		(byte)0x00, (byte)0x7C, (byte)0xC6, (byte)0xFE, (byte)0xC6, (byte)0x7C, (byte)0x00, (byte)0x00, // Char 233 (.)
		(byte)0x00, (byte)0x7E, (byte)0xC3, (byte)0xC3, (byte)0xC3, (byte)0x66, (byte)0xE7, (byte)0x00, // Char 234 (.)
		(byte)0x1E, (byte)0x19, (byte)0x3C, (byte)0x66, (byte)0xC6, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 235 (.)
		(byte)0x00, (byte)0x00, (byte)0x66, (byte)0x99, (byte)0x99, (byte)0x66, (byte)0x00, (byte)0x00, // Char 236 (.)
		(byte)0x00, (byte)0x03, (byte)0x7C, (byte)0xCE, (byte)0xE6, (byte)0x7C, (byte)0xC0, (byte)0x00, // Char 237 (.)
		(byte)0x00, (byte)0x3E, (byte)0xC0, (byte)0xFE, (byte)0xC0, (byte)0x3E, (byte)0x00, (byte)0x00, // Char 238 (.)
		(byte)0x00, (byte)0x7E, (byte)0xC3, (byte)0xC3, (byte)0xC3, (byte)0xC3, (byte)0x00, (byte)0x00, // Char 239 (.)
		(byte)0x00, (byte)0xFE, (byte)0x00, (byte)0xFE, (byte)0x00, (byte)0xFE, (byte)0x00, (byte)0x00, // Char 240 (.)
		(byte)0x08, (byte)0x08, (byte)0x3E, (byte)0x08, (byte)0x08, (byte)0x00, (byte)0x3E, (byte)0x00, // Char 241 (.)
		(byte)0x30, (byte)0x08, (byte)0x04, (byte)0x08, (byte)0x30, (byte)0x00, (byte)0x7E, (byte)0x00, // Char 242 (.)
		(byte)0x18, (byte)0x20, (byte)0x40, (byte)0x20, (byte)0x18, (byte)0x00, (byte)0xFC, (byte)0x00, // Char 243 (.)
		(byte)0x00, (byte)0x0E, (byte)0x11, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, // Char 244 (.)
		(byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x90, (byte)0x60, (byte)0x00, // Char 245 (.)
		(byte)0x00, (byte)0x08, (byte)0x00, (byte)0x3E, (byte)0x00, (byte)0x08, (byte)0x00, (byte)0x00, // Char 246 (.)
		(byte)0x00, (byte)0x76, (byte)0xDC, (byte)0x00, (byte)0x76, (byte)0xDC, (byte)0x00, (byte)0x00, // Char 247 (.)
		(byte)0x3C, (byte)0x66, (byte)0x3C, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 248 (.)
		(byte)0x00, (byte)0x18, (byte)0x3C, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 249 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, // Char 250 (.)
		(byte)0x0F, (byte)0x0C, (byte)0x0C, (byte)0x0C, (byte)0xEC, (byte)0x6C, (byte)0x38, (byte)0x00, // Char 251 (.)
		(byte)0x50, (byte)0x68, (byte)0x48, (byte)0x48, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 252 (.)
		(byte)0xF0, (byte)0x30, (byte)0xC0, (byte)0xF0, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 253 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x3C, (byte)0x3C, (byte)0x3C, (byte)0x3C, (byte)0x00, // Char 254 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 255 (.)
		// CP111.pf  
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 000 (.)
		(byte)0x7E, (byte)0x81, (byte)0xA5, (byte)0x81, (byte)0xBD, (byte)0x99, (byte)0x81, (byte)0x7E, // Char 001 (.)
		(byte)0x7E, (byte)0xFF, (byte)0xDB, (byte)0xFF, (byte)0xC3, (byte)0xE7, (byte)0xFF, (byte)0x7E, // Char 002 (.)
		(byte)0x6C, (byte)0xFE, (byte)0xFE, (byte)0xFE, (byte)0x7C, (byte)0x38, (byte)0x10, (byte)0x00, // Char 003 (.)
		(byte)0x10, (byte)0x38, (byte)0x7C, (byte)0xFE, (byte)0x7C, (byte)0x38, (byte)0x10, (byte)0x00, // Char 004 (.)
		(byte)0x38, (byte)0x7C, (byte)0xEE, (byte)0xEE, (byte)0xEE, (byte)0x38, (byte)0x38, (byte)0x7C, // Char 005 (.)
		(byte)0x00, (byte)0x10, (byte)0x38, (byte)0x7C, (byte)0xFE, (byte)0x7C, (byte)0x38, (byte)0x7C, // Char 006 (.)
		(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x3C, (byte)0x3C, (byte)0x18, (byte)0x00, (byte)0x00, // Char 007 (.)
		(byte)0xFF, (byte)0xFF, (byte)0xE7, (byte)0xC3, (byte)0xC3, (byte)0xE7, (byte)0xFF, (byte)0xFF, // Char 008 (.)
		(byte)0x00, (byte)0x3C, (byte)0x66, (byte)0x42, (byte)0x42, (byte)0x66, (byte)0x3C, (byte)0x00, // Char 009 (.)
		(byte)0xFF, (byte)0xC3, (byte)0x99, (byte)0xBD, (byte)0xBD, (byte)0x99, (byte)0xC3, (byte)0xFF, // Char 010 (.)
		(byte)0x0F, (byte)0x07, (byte)0x0F, (byte)0x7D, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, // Char 011 (.)
		(byte)0x3C, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x3C, (byte)0x18, (byte)0x7E, (byte)0x18, // Char 012 (.)
		(byte)0x3F, (byte)0x33, (byte)0x3F, (byte)0x30, (byte)0x30, (byte)0x70, (byte)0xF0, (byte)0xE0, // Char 013 (.)
		(byte)0x7F, (byte)0x63, (byte)0x7F, (byte)0x63, (byte)0x63, (byte)0x67, (byte)0xE6, (byte)0xC0, // Char 014 (.)
		(byte)0x18, (byte)0xDB, (byte)0x3C, (byte)0xE7, (byte)0xE7, (byte)0x3C, (byte)0xDB, (byte)0x18, // Char 015 (.)
		(byte)0x80, (byte)0xE0, (byte)0xF8, (byte)0xFE, (byte)0xF8, (byte)0xE0, (byte)0x80, (byte)0x00, // Char 016 (.)
		(byte)0x02, (byte)0x0E, (byte)0x3E, (byte)0xFE, (byte)0x3E, (byte)0x0E, (byte)0x02, (byte)0x00, // Char 017 (.)
		(byte)0x18, (byte)0x3C, (byte)0x7E, (byte)0x18, (byte)0x18, (byte)0x7E, (byte)0x3C, (byte)0x18, // Char 018 (.)
		(byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x00, (byte)0x66, (byte)0x00, // Char 019 (.)
		(byte)0x7F, (byte)0xDB, (byte)0xDB, (byte)0x7B, (byte)0x1B, (byte)0x1B, (byte)0x1B, (byte)0x00, // Char 020 (.)
		(byte)0x3C, (byte)0x66, (byte)0x38, (byte)0x6C, (byte)0x6C, (byte)0x38, (byte)0xCC, (byte)0x78, // Char 021 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x7E, (byte)0x7E, (byte)0x7E, (byte)0x00, // Char 022 (.)
		(byte)0x18, (byte)0x3C, (byte)0x7E, (byte)0x18, (byte)0x7E, (byte)0x3C, (byte)0x18, (byte)0x7E, // Char 023 (.)
		(byte)0x18, (byte)0x3C, (byte)0x7E, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, // Char 024 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x7E, (byte)0x3C, (byte)0x18, (byte)0x00, // Char 025 (.)
		(byte)0x00, (byte)0x18, (byte)0x0C, (byte)0xFE, (byte)0x0C, (byte)0x18, (byte)0x00, (byte)0x00, // Char 026 (.)
		(byte)0x00, (byte)0x30, (byte)0x60, (byte)0xFE, (byte)0x60, (byte)0x30, (byte)0x00, (byte)0x00, // Char 027 (.)
		(byte)0x00, (byte)0x00, (byte)0xC0, (byte)0xC0, (byte)0xC0, (byte)0xFE, (byte)0x00, (byte)0x00, // Char 028 (.)
		(byte)0x00, (byte)0x24, (byte)0x66, (byte)0xFF, (byte)0x66, (byte)0x24, (byte)0x00, (byte)0x00, // Char 029 (.)
		(byte)0x00, (byte)0x18, (byte)0x3C, (byte)0x7E, (byte)0xFF, (byte)0xFF, (byte)0x00, (byte)0x00, // Char 030 (.)
		(byte)0x00, (byte)0xFF, (byte)0xFF, (byte)0x7E, (byte)0x3C, (byte)0x18, (byte)0x00, (byte)0x00, // Char 031 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 032 ( )
		(byte)0x30, (byte)0x78, (byte)0x78, (byte)0x30, (byte)0x30, (byte)0x00, (byte)0x30, (byte)0x00, // Char 033 (!)
		(byte)0x6C, (byte)0x6C, (byte)0x28, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 034 (")
		(byte)0x6C, (byte)0x6C, (byte)0xFE, (byte)0x6C, (byte)0xFE, (byte)0x6C, (byte)0x6C, (byte)0x00, // Char 035 (#)
		(byte)0x18, (byte)0x7E, (byte)0xC0, (byte)0x7C, (byte)0x06, (byte)0xFC, (byte)0x18, (byte)0x00, // Char 036 ($)
		(byte)0x00, (byte)0xC6, (byte)0xCC, (byte)0x18, (byte)0x30, (byte)0x66, (byte)0xC6, (byte)0x00, // Char 037 (%)
		(byte)0x38, (byte)0x6C, (byte)0x38, (byte)0x76, (byte)0xDC, (byte)0xCC, (byte)0x76, (byte)0x00, // Char 038 (&)
		(byte)0x30, (byte)0x30, (byte)0x60, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 039 (')
		(byte)0x18, (byte)0x30, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x00, // Char 040 (()
		(byte)0x60, (byte)0x30, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x00, // Char 041 ())
		(byte)0x00, (byte)0x66, (byte)0x3C, (byte)0xFF, (byte)0x3C, (byte)0x66, (byte)0x00, (byte)0x00, // Char 042 (*)
		(byte)0x00, (byte)0x30, (byte)0x30, (byte)0xFC, (byte)0x30, (byte)0x30, (byte)0x00, (byte)0x00, // Char 043 (+)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x60, // Char 044 (,)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFC, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 045 (-)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x00, // Char 046 (.)
		(byte)0x06, (byte)0x0C, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0xC0, (byte)0x80, (byte)0x00, // Char 047 (/)
		(byte)0x7C, (byte)0xC6, (byte)0xC6, (byte)0xD6, (byte)0xC6, (byte)0xC6, (byte)0x7C, (byte)0x00, // Char 048 (0)
		(byte)0x30, (byte)0x70, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0xFC, (byte)0x00, // Char 049 (1)
		(byte)0x78, (byte)0xCC, (byte)0x0C, (byte)0x38, (byte)0x60, (byte)0xCC, (byte)0xFC, (byte)0x00, // Char 050 (2)
		(byte)0x78, (byte)0xCC, (byte)0x0C, (byte)0x38, (byte)0x0C, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 051 (3)
		(byte)0x1C, (byte)0x3C, (byte)0x6C, (byte)0xCC, (byte)0xFE, (byte)0x0C, (byte)0x1E, (byte)0x00, // Char 052 (4)
		(byte)0xFC, (byte)0xC0, (byte)0xF8, (byte)0x0C, (byte)0x0C, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 053 (5)
		(byte)0x38, (byte)0x60, (byte)0xC0, (byte)0xF8, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 054 (6)
		(byte)0xFC, (byte)0xCC, (byte)0x0C, (byte)0x18, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x00, // Char 055 (7)
		(byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 056 (8)
		(byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0x7C, (byte)0x0C, (byte)0x18, (byte)0x70, (byte)0x00, // Char 057 (9)
		(byte)0x00, (byte)0x30, (byte)0x30, (byte)0x00, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x00, // Char 058 (:)
		(byte)0x00, (byte)0x30, (byte)0x30, (byte)0x00, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x60, // Char 059 (;)
		(byte)0x18, (byte)0x30, (byte)0x60, (byte)0xC0, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x00, // Char 060 (<)
		(byte)0x00, (byte)0x00, (byte)0xFC, (byte)0x00, (byte)0x00, (byte)0xFC, (byte)0x00, (byte)0x00, // Char 061 (=)
		(byte)0x60, (byte)0x30, (byte)0x18, (byte)0x0C, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x00, // Char 062 (>)
		(byte)0x78, (byte)0xCC, (byte)0x0C, (byte)0x18, (byte)0x30, (byte)0x00, (byte)0x30, (byte)0x00, // Char 063 (?)
		(byte)0x7C, (byte)0xC6, (byte)0xDE, (byte)0xDE, (byte)0xDC, (byte)0xC0, (byte)0x78, (byte)0x00, // Char 064 (@)
		(byte)0x30, (byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0xFC, (byte)0xCC, (byte)0xCC, (byte)0x00, // Char 065 (A)
		(byte)0xFC, (byte)0x66, (byte)0x66, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0xFC, (byte)0x00, // Char 066 (B)
		(byte)0x3C, (byte)0x66, (byte)0xC0, (byte)0xC0, (byte)0xC0, (byte)0x66, (byte)0x3C, (byte)0x00, // Char 067 (C)
		(byte)0xF8, (byte)0x6C, (byte)0x66, (byte)0x66, (byte)0x66, (byte)0x6C, (byte)0xF8, (byte)0x00, // Char 068 (D)
		(byte)0xFE, (byte)0x62, (byte)0x68, (byte)0x78, (byte)0x68, (byte)0x62, (byte)0xFE, (byte)0x00, // Char 069 (E)
		(byte)0xFE, (byte)0x62, (byte)0x68, (byte)0x78, (byte)0x68, (byte)0x60, (byte)0xF0, (byte)0x00, // Char 070 (F)
		(byte)0x3C, (byte)0x66, (byte)0xC0, (byte)0xC0, (byte)0xCE, (byte)0x66, (byte)0x3E, (byte)0x00, // Char 071 (G)
		(byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xFC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x00, // Char 072 (H)
		(byte)0x78, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x78, (byte)0x00, // Char 073 (I)
		(byte)0x1E, (byte)0x0C, (byte)0x0C, (byte)0x0C, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 074 (J)
		(byte)0xE6, (byte)0x66, (byte)0x6C, (byte)0x78, (byte)0x6C, (byte)0x66, (byte)0xE6, (byte)0x00, // Char 075 (K)
		(byte)0xF0, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x62, (byte)0x66, (byte)0xFE, (byte)0x00, // Char 076 (L)
		(byte)0xC6, (byte)0xEE, (byte)0xFE, (byte)0xFE, (byte)0xD6, (byte)0xC6, (byte)0xC6, (byte)0x00, // Char 077 (M)
		(byte)0xC6, (byte)0xE6, (byte)0xF6, (byte)0xDE, (byte)0xCE, (byte)0xC6, (byte)0xC6, (byte)0x00, // Char 078 (N)
		(byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x6C, (byte)0x38, (byte)0x00, // Char 079 (O)
		(byte)0xFC, (byte)0x66, (byte)0x66, (byte)0x7C, (byte)0x60, (byte)0x60, (byte)0xF0, (byte)0x00, // Char 080 (P)
		(byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xDC, (byte)0x78, (byte)0x1C, (byte)0x00, // Char 081 (Q)
		(byte)0xFC, (byte)0x66, (byte)0x66, (byte)0x7C, (byte)0x6C, (byte)0x66, (byte)0xE6, (byte)0x00, // Char 082 (R)
		(byte)0x78, (byte)0xCC, (byte)0xC0, (byte)0x78, (byte)0x0C, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 083 (S)
		(byte)0xFC, (byte)0xB4, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x78, (byte)0x00, // Char 084 (T)
		(byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xFC, (byte)0x00, // Char 085 (U)
		(byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x30, (byte)0x00, // Char 086 (V)
		(byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0xD6, (byte)0xFE, (byte)0xEE, (byte)0xC6, (byte)0x00, // Char 087 (W)
		(byte)0xC6, (byte)0x6C, (byte)0x38, (byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0xC6, (byte)0x00, // Char 088 (X)
		(byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x30, (byte)0x30, (byte)0x78, (byte)0x00, // Char 089 (Y)
		(byte)0xFE, (byte)0xC6, (byte)0x8C, (byte)0x18, (byte)0x32, (byte)0x66, (byte)0xFE, (byte)0x00, // Char 090 (Z)
		(byte)0x78, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x78, (byte)0x00, // Char 091 ([)
		(byte)0xC0, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x0C, (byte)0x06, (byte)0x02, (byte)0x00, // Char 092 (\)
		(byte)0x78, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x78, (byte)0x00, // Char 093 (])
		(byte)0x10, (byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 094 (^)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, // Char 095 (_)
		(byte)0x30, (byte)0x18, (byte)0x0C, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 096 (`)
		(byte)0x00, (byte)0x00, (byte)0x78, (byte)0x0C, (byte)0x7C, (byte)0xCC, (byte)0x76, (byte)0x00, // Char 097 (a)
		(byte)0xE0, (byte)0x60, (byte)0x60, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0xDC, (byte)0x00, // Char 098 (b)
		(byte)0x00, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0xC0, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 099 (c)
		(byte)0x1C, (byte)0x0C, (byte)0x0C, (byte)0x7C, (byte)0xCC, (byte)0xCC, (byte)0x76, (byte)0x00, // Char 100 (d)
		(byte)0x00, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0xFC, (byte)0xC0, (byte)0x78, (byte)0x00, // Char 101 (e)
		(byte)0x38, (byte)0x6C, (byte)0x60, (byte)0xF0, (byte)0x60, (byte)0x60, (byte)0xF0, (byte)0x00, // Char 102 (f)
		(byte)0x00, (byte)0x00, (byte)0x76, (byte)0xCC, (byte)0xCC, (byte)0x7C, (byte)0x0C, (byte)0xF8, // Char 103 (g)
		(byte)0xE0, (byte)0x60, (byte)0x6C, (byte)0x76, (byte)0x66, (byte)0x66, (byte)0xE6, (byte)0x00, // Char 104 (h)
		(byte)0x30, (byte)0x00, (byte)0x70, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x78, (byte)0x00, // Char 105 (i)
		(byte)0x0C, (byte)0x00, (byte)0x0C, (byte)0x0C, (byte)0x0C, (byte)0xCC, (byte)0xCC, (byte)0x78, // Char 106 (j)
		(byte)0xE0, (byte)0x60, (byte)0x66, (byte)0x6C, (byte)0x78, (byte)0x6C, (byte)0xE6, (byte)0x00, // Char 107 (k)
		(byte)0x70, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x78, (byte)0x00, // Char 108 (l)
		(byte)0x00, (byte)0x00, (byte)0xCC, (byte)0xFE, (byte)0xD6, (byte)0xD6, (byte)0xC6, (byte)0x00, // Char 109 (m)
		(byte)0x00, (byte)0x00, (byte)0xF8, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x00, // Char 110 (n)
		(byte)0x00, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 111 (o)
		(byte)0x00, (byte)0x00, (byte)0xDC, (byte)0x66, (byte)0x66, (byte)0x7C, (byte)0x60, (byte)0xF0, // Char 112 (p)
		(byte)0x00, (byte)0x00, (byte)0x76, (byte)0xCC, (byte)0xCC, (byte)0x7C, (byte)0x0C, (byte)0x1E, // Char 113 (q)
		(byte)0x00, (byte)0x00, (byte)0xDC, (byte)0x76, (byte)0x66, (byte)0x60, (byte)0xF0, (byte)0x00, // Char 114 (r)
		(byte)0x00, (byte)0x00, (byte)0x7C, (byte)0xC0, (byte)0x78, (byte)0x0C, (byte)0xF8, (byte)0x00, // Char 115 (s)
		(byte)0x10, (byte)0x30, (byte)0x7C, (byte)0x30, (byte)0x30, (byte)0x34, (byte)0x18, (byte)0x00, // Char 116 (t)
		(byte)0x00, (byte)0x00, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x76, (byte)0x00, // Char 117 (u)
		(byte)0x00, (byte)0x00, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x30, (byte)0x00, // Char 118 (v)
		(byte)0x00, (byte)0x00, (byte)0xC6, (byte)0xD6, (byte)0xD6, (byte)0xFE, (byte)0x6C, (byte)0x00, // Char 119 (w)
		(byte)0x00, (byte)0x00, (byte)0xC6, (byte)0x6C, (byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0x00, // Char 120 (x)
		(byte)0x00, (byte)0x00, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x7C, (byte)0x0C, (byte)0xF8, // Char 121 (y)
		(byte)0x00, (byte)0x00, (byte)0xFC, (byte)0x98, (byte)0x30, (byte)0x64, (byte)0xFC, (byte)0x00, // Char 122 (z)
		(byte)0x1C, (byte)0x30, (byte)0x30, (byte)0xE0, (byte)0x30, (byte)0x30, (byte)0x1C, (byte)0x00, // Char 123 ({)
		(byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x00, // Char 124 (|)
		(byte)0xE0, (byte)0x30, (byte)0x30, (byte)0x1C, (byte)0x30, (byte)0x30, (byte)0xE0, (byte)0x00, // Char 125 (})
		(byte)0x76, (byte)0xDC, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 126 (~)
		(byte)0x00, (byte)0x10, (byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0xC6, (byte)0xFE, (byte)0x00, // Char 127 (.)
		(byte)0x30, (byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0xFC, (byte)0xCC, (byte)0xCC, (byte)0x00, // Char 128 (.)
		(byte)0xFC, (byte)0x66, (byte)0x66, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0xFC, (byte)0x00, // Char 129 (.)
		(byte)0xFE, (byte)0x62, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0x60, (byte)0xF0, (byte)0x00, // Char 130 (.)
		(byte)0x10, (byte)0x38, (byte)0x38, (byte)0x6C, (byte)0x6C, (byte)0xC6, (byte)0xFE, (byte)0x00, // Char 131 (.)
		(byte)0xFE, (byte)0x62, (byte)0x68, (byte)0x78, (byte)0x68, (byte)0x62, (byte)0xFE, (byte)0x00, // Char 132 (.)
		(byte)0xFE, (byte)0xC6, (byte)0x8C, (byte)0x18, (byte)0x32, (byte)0x66, (byte)0xFE, (byte)0x00, // Char 133 (.)
		(byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xFC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x00, // Char 134 (.)
		(byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0xFE, (byte)0xC6, (byte)0x6C, (byte)0x38, (byte)0x00, // Char 135 (.)
		(byte)0x78, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x78, (byte)0x00, // Char 136 (.)
		(byte)0xE6, (byte)0x66, (byte)0x6C, (byte)0x78, (byte)0x6C, (byte)0x66, (byte)0xE6, (byte)0x00, // Char 137 (.)
		(byte)0x10, (byte)0x38, (byte)0x38, (byte)0x6C, (byte)0x6C, (byte)0xC6, (byte)0xC6, (byte)0x00, // Char 138 (.)
		(byte)0xC6, (byte)0xEE, (byte)0xFE, (byte)0xFE, (byte)0xD6, (byte)0xC6, (byte)0xC6, (byte)0x00, // Char 139 (.)
		(byte)0xC6, (byte)0xE6, (byte)0xF6, (byte)0xDE, (byte)0xCE, (byte)0xC6, (byte)0xC6, (byte)0x00, // Char 140 (.)
		(byte)0xFC, (byte)0xCC, (byte)0x00, (byte)0x78, (byte)0x00, (byte)0xCC, (byte)0xFC, (byte)0x00, // Char 141 (.)
		(byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x6C, (byte)0x38, (byte)0x00, // Char 142 (.)
		(byte)0xFC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x00, // Char 143 (.)
		(byte)0xFC, (byte)0x66, (byte)0x66, (byte)0x7C, (byte)0x60, (byte)0x60, (byte)0xF0, (byte)0x00, // Char 144 (.)
		(byte)0xFC, (byte)0xCC, (byte)0x60, (byte)0x30, (byte)0x60, (byte)0xCC, (byte)0xFC, (byte)0x00, // Char 145 (.)
		(byte)0xFC, (byte)0xB4, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x78, (byte)0x00, // Char 146 (.)
		(byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x30, (byte)0x30, (byte)0x78, (byte)0x00, // Char 147 (.)
		(byte)0x10, (byte)0x7C, (byte)0xD6, (byte)0xD6, (byte)0xD6, (byte)0x7C, (byte)0x10, (byte)0x00, // Char 148 (.)
		(byte)0xC6, (byte)0x6C, (byte)0x38, (byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0xC6, (byte)0x00, // Char 149 (.)
		(byte)0xD6, (byte)0xD6, (byte)0xD6, (byte)0xD6, (byte)0x7C, (byte)0x10, (byte)0x38, (byte)0x00, // Char 150 (.)
		(byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0xC6, (byte)0xC6, (byte)0x6C, (byte)0xEE, (byte)0x00, // Char 151 (.)
		(byte)0x00, (byte)0x00, (byte)0x74, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x76, (byte)0x00, // Char 152 (.)
		(byte)0x00, (byte)0x78, (byte)0xCC, (byte)0xF8, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 153 (.)
		(byte)0x00, (byte)0x00, (byte)0xC6, (byte)0x6C, (byte)0x38, (byte)0x6C, (byte)0x6C, (byte)0x38, // Char 154 (.)
		(byte)0x1C, (byte)0x30, (byte)0x18, (byte)0x7C, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 155 (.)
		(byte)0x00, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0x60, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 156 (.)
		(byte)0xFC, (byte)0x30, (byte)0x60, (byte)0xC0, (byte)0xC0, (byte)0x78, (byte)0x0C, (byte)0x38, // Char 157 (.)
		(byte)0x00, (byte)0x00, (byte)0xF8, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x0C, // Char 158 (.)
		(byte)0x78, (byte)0xCC, (byte)0x7C, (byte)0x0C, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 159 (.)
		(byte)0x00, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x18, (byte)0x00, // Char 160 (.)
		(byte)0x00, (byte)0x00, (byte)0xE6, (byte)0x6C, (byte)0x78, (byte)0x6C, (byte)0xE6, (byte)0x00, // Char 161 (.)
		(byte)0x70, (byte)0x98, (byte)0x18, (byte)0x38, (byte)0x6C, (byte)0xCC, (byte)0xCC, (byte)0x00, // Char 162 (.)
		(byte)0x00, (byte)0x00, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xF6, (byte)0xC0, // Char 163 (.)
		(byte)0x00, (byte)0x00, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x30, (byte)0x00, // Char 164 (.)
		(byte)0xFC, (byte)0x60, (byte)0x78, (byte)0xC0, (byte)0xC0, (byte)0x78, (byte)0x0C, (byte)0x38, // Char 165 (.)
		(byte)0x00, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 166 (.)
		(byte)0x00, (byte)0x00, (byte)0xFE, (byte)0x6C, (byte)0x6C, (byte)0x6C, (byte)0x6C, (byte)0x00, // Char 167 (.)
		(byte)0x00, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xF8, (byte)0xC0, // Char 168 (.)
		(byte)0x00, (byte)0x00, (byte)0x7E, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 169 (.)
		(byte)0x00, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0xC0, (byte)0x78, (byte)0x0C, (byte)0x38, // Char 170 (.)
		(byte)0x00, (byte)0x00, (byte)0xFC, (byte)0x30, (byte)0x30, (byte)0x34, (byte)0x18, (byte)0x00, // Char 171 (.)
		(byte)0x00, (byte)0x00, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 172 (.)
		(byte)0x00, (byte)0x00, (byte)0x5C, (byte)0xD6, (byte)0xD6, (byte)0xD6, (byte)0x7C, (byte)0x10, // Char 173 (.)
		(byte)0x00, (byte)0x00, (byte)0xC6, (byte)0x6C, (byte)0x38, (byte)0x38, (byte)0x6C, (byte)0xC6, // Char 174 (.)
		(byte)0x00, (byte)0x10, (byte)0xD6, (byte)0xD6, (byte)0xD6, (byte)0xD6, (byte)0x7C, (byte)0x10, // Char 175 (.)
		(byte)0x22, (byte)0x88, (byte)0x22, (byte)0x88, (byte)0x22, (byte)0x88, (byte)0x22, (byte)0x88, // Char 176 (.)
		(byte)0x55, (byte)0xAA, (byte)0x55, (byte)0xAA, (byte)0x55, (byte)0xAA, (byte)0x55, (byte)0xAA, // Char 177 (.)
		(byte)0xDD, (byte)0x77, (byte)0xDD, (byte)0x77, (byte)0xDD, (byte)0x77, (byte)0xDD, (byte)0x77, // Char 178 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 179 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xF8, (byte)0x18, (byte)0x18, (byte)0x18, // Char 180 (.)
		(byte)0x18, (byte)0x18, (byte)0xF8, (byte)0x18, (byte)0xF8, (byte)0x18, (byte)0x18, (byte)0x18, // Char 181 (.)
		(byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xF6, (byte)0x36, (byte)0x36, (byte)0x36, // Char 182 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFE, (byte)0x36, (byte)0x36, (byte)0x36, // Char 183 (.)
		(byte)0x00, (byte)0x00, (byte)0xF8, (byte)0x18, (byte)0xF8, (byte)0x18, (byte)0x18, (byte)0x18, // Char 184 (.)
		(byte)0x36, (byte)0x36, (byte)0xF6, (byte)0x06, (byte)0xF6, (byte)0x36, (byte)0x36, (byte)0x36, // Char 185 (.)
		(byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, // Char 186 (.)
		(byte)0x00, (byte)0x00, (byte)0xFE, (byte)0x06, (byte)0xF6, (byte)0x36, (byte)0x36, (byte)0x36, // Char 187 (.)
		(byte)0x36, (byte)0x36, (byte)0xF6, (byte)0x06, (byte)0xFE, (byte)0x00, (byte)0x00, (byte)0x00, // Char 188 (.)
		(byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xFE, (byte)0x00, (byte)0x00, (byte)0x00, // Char 189 (.)
		(byte)0x18, (byte)0x18, (byte)0xF8, (byte)0x18, (byte)0xF8, (byte)0x00, (byte)0x00, (byte)0x00, // Char 190 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xF8, (byte)0x18, (byte)0x18, (byte)0x18, // Char 191 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x1F, (byte)0x00, (byte)0x00, (byte)0x00, // Char 192 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, // Char 193 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x18, (byte)0x18, (byte)0x18, // Char 194 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x1F, (byte)0x18, (byte)0x18, (byte)0x18, // Char 195 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, // Char 196 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xFF, (byte)0x18, (byte)0x18, (byte)0x18, // Char 197 (.)
		(byte)0x18, (byte)0x18, (byte)0x1F, (byte)0x18, (byte)0x1F, (byte)0x18, (byte)0x18, (byte)0x18, // Char 198 (.)
		(byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x37, (byte)0x36, (byte)0x36, (byte)0x36, // Char 199 (.)
		(byte)0x36, (byte)0x36, (byte)0x37, (byte)0x30, (byte)0x3F, (byte)0x00, (byte)0x00, (byte)0x00, // Char 200 (.)
		(byte)0x00, (byte)0x00, (byte)0x3F, (byte)0x30, (byte)0x37, (byte)0x36, (byte)0x36, (byte)0x36, // Char 201 (.)
		(byte)0x36, (byte)0x36, (byte)0xF7, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, // Char 202 (.)
		(byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0xF7, (byte)0x36, (byte)0x36, (byte)0x36, // Char 203 (.)
		(byte)0x36, (byte)0x36, (byte)0x37, (byte)0x30, (byte)0x37, (byte)0x36, (byte)0x36, (byte)0x36, // Char 204 (.)
		(byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, // Char 205 (.)
		(byte)0x36, (byte)0x36, (byte)0xF7, (byte)0x00, (byte)0xF7, (byte)0x36, (byte)0x36, (byte)0x36, // Char 206 (.)
		(byte)0x18, (byte)0x18, (byte)0xFF, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, // Char 207 (.)
		(byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, // Char 208 (.)
		(byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x00, (byte)0xFF, (byte)0x18, (byte)0x18, (byte)0x18, // Char 209 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0x36, (byte)0x36, (byte)0x36, // Char 210 (.)
		(byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0x3F, (byte)0x00, (byte)0x00, (byte)0x00, // Char 211 (.)
		(byte)0x18, (byte)0x18, (byte)0x1F, (byte)0x18, (byte)0x1F, (byte)0x00, (byte)0x00, (byte)0x00, // Char 212 (.)
		(byte)0x00, (byte)0x00, (byte)0x1F, (byte)0x18, (byte)0x1F, (byte)0x18, (byte)0x18, (byte)0x18, // Char 213 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x3F, (byte)0x36, (byte)0x36, (byte)0x36, // Char 214 (.)
		(byte)0x36, (byte)0x36, (byte)0x36, (byte)0x36, (byte)0xFF, (byte)0x36, (byte)0x36, (byte)0x36, // Char 215 (.)
		(byte)0x18, (byte)0x18, (byte)0xFF, (byte)0x18, (byte)0xFF, (byte)0x18, (byte)0x18, (byte)0x18, // Char 216 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xF8, (byte)0x00, (byte)0x00, (byte)0x00, // Char 217 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x1F, (byte)0x18, (byte)0x18, (byte)0x18, // Char 218 (.)
		(byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, // Char 219 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, // Char 220 (.)
		(byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, (byte)0xF0, // Char 221 (.)
		(byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, (byte)0x0F, // Char 222 (.)
		(byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0xFF, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 223 (.)
		(byte)0x00, (byte)0x00, (byte)0x6C, (byte)0xC6, (byte)0xD6, (byte)0xFE, (byte)0x6C, (byte)0x00, // Char 224 (.)
		(byte)0x0E, (byte)0x00, (byte)0x74, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x76, (byte)0x00, // Char 225 (.)
		(byte)0x1C, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0x60, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 226 (.)
		(byte)0x1C, (byte)0x00, (byte)0xF8, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x0C, // Char 227 (.)
		(byte)0xCC, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x18, (byte)0x00, // Char 228 (.)
		(byte)0x38, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x30, (byte)0x18, (byte)0x00, // Char 229 (.)
		(byte)0x1C, (byte)0x00, (byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 230 (.)
		(byte)0x1C, (byte)0x00, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 231 (.)
		(byte)0xCC, (byte)0x00, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x78, (byte)0x00, // Char 232 (.)
		(byte)0x0E, (byte)0x00, (byte)0x6C, (byte)0xC6, (byte)0xD6, (byte)0xFE, (byte)0x6C, (byte)0x00, // Char 233 (.)
		(byte)0x38, (byte)0x6C, (byte)0xC6, (byte)0xC6, (byte)0x6C, (byte)0x6C, (byte)0xEE, (byte)0x00, // Char 234 (.)
		(byte)0x38, (byte)0x6C, (byte)0x64, (byte)0xF0, (byte)0x60, (byte)0xE6, (byte)0xFC, (byte)0x00, // Char 235 (.)
		(byte)0x00, (byte)0x00, (byte)0x7E, (byte)0xDB, (byte)0xDB, (byte)0x7E, (byte)0x00, (byte)0x00, // Char 236 (.)
		(byte)0x06, (byte)0x0C, (byte)0x7E, (byte)0xDB, (byte)0xDB, (byte)0x7E, (byte)0x60, (byte)0xC0, // Char 237 (.)
		(byte)0x38, (byte)0x60, (byte)0xC0, (byte)0xF8, (byte)0xC0, (byte)0x60, (byte)0x38, (byte)0x00, // Char 238 (.)
		(byte)0x78, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0xCC, (byte)0x00, // Char 239 (.)
		(byte)0x00, (byte)0xFC, (byte)0x00, (byte)0xFC, (byte)0x00, (byte)0xFC, (byte)0x00, (byte)0x00, // Char 240 (.)
		(byte)0x30, (byte)0x30, (byte)0xFC, (byte)0x30, (byte)0x30, (byte)0x00, (byte)0xFC, (byte)0x00, // Char 241 (.)
		(byte)0x60, (byte)0x30, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x00, (byte)0xFC, (byte)0x00, // Char 242 (.)
		(byte)0x18, (byte)0x30, (byte)0x60, (byte)0x30, (byte)0x18, (byte)0x00, (byte)0xFC, (byte)0x00, // Char 243 (.)
		(byte)0x0E, (byte)0x1B, (byte)0x1B, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 244 (.)
		(byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0xD8, (byte)0xD8, (byte)0x70, // Char 245 (.)
		(byte)0x30, (byte)0x30, (byte)0x00, (byte)0xFC, (byte)0x00, (byte)0x30, (byte)0x30, (byte)0x00, // Char 246 (.)
		(byte)0x00, (byte)0x76, (byte)0xDC, (byte)0x00, (byte)0x76, (byte)0xDC, (byte)0x00, (byte)0x00, // Char 247 (.)
		(byte)0x38, (byte)0x6C, (byte)0x6C, (byte)0x38, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 248 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, // Char 249 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 250 (.)
		(byte)0x0F, (byte)0x0C, (byte)0x0C, (byte)0x0C, (byte)0xEC, (byte)0x6C, (byte)0x3C, (byte)0x1C, // Char 251 (.)
		(byte)0x78, (byte)0x6C, (byte)0x6C, (byte)0x6C, (byte)0x6C, (byte)0x00, (byte)0x00, (byte)0x00, // Char 252 (.)
		(byte)0x38, (byte)0x4C, (byte)0x18, (byte)0x30, (byte)0x7C, (byte)0x00, (byte)0x00, (byte)0x00, // Char 253 (.)
		(byte)0x00, (byte)0x00, (byte)0x3C, (byte)0x3C, (byte)0x3C, (byte)0x3C, (byte)0x00, (byte)0x00, // Char 254 (.)
		(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 255 (.)
        // numbers set 1
    	(byte)0x3C, (byte)0x42, (byte)0x46, (byte)0x4A, (byte)0x52, (byte)0x62, (byte)0x42, (byte)0x3C, // Char 000 (0)
    	(byte)0x08, (byte)0x18, (byte)0x38, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3C, // Char 001 (1)
    	(byte)0x18, (byte)0x3C, (byte)0x66, (byte)0x0C, (byte)0x18, (byte)0x30, (byte)0x60, (byte)0x7E, // Char 002 (2)
    	(byte)0x3C, (byte)0x7E, (byte)0x06, (byte)0x3E, (byte)0x1E, (byte)0x06, (byte)0x7E, (byte)0x3C, // Char 003 (3)
    	(byte)0x60, (byte)0x60, (byte)0x6C, (byte)0x6C, (byte)0x7F, (byte)0x7F, (byte)0x0C, (byte)0x0C, // Char 004 (4)
    	(byte)0x7E, (byte)0x7C, (byte)0x60, (byte)0x7C, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x7C, // Char 005 (5)
    	(byte)0x0E, (byte)0x1C, (byte)0x38, (byte)0x70, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0x3E, // Char 006 (6)
    	(byte)0x3E, (byte)0x36, (byte)0x06, (byte)0x0C, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 007 (7)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x7E, // Char 008 (8)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x3C, // Char 009 (9)
    	// numbers set 2
    	(byte)0x00, (byte)0x1C, (byte)0x22, (byte)0x26, (byte)0x2A, (byte)0x32, (byte)0x22, (byte)0x1C, // Char 010 (0)
    	(byte)0x00, (byte)0x18, (byte)0x38, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x3C, (byte)0x00, // Char 011 (1)
    	(byte)0x00, (byte)0x1C, (byte)0x24, (byte)0x0C, (byte)0x18, (byte)0x30, (byte)0x20, (byte)0x3C, // Char 012 (2)
    	(byte)0x3C, (byte)0x46, (byte)0x06, (byte)0x3E, (byte)0x06, (byte)0x06, (byte)0x46, (byte)0x3C, // Char 013 (3)
    	(byte)0x20, (byte)0x20, (byte)0x28, (byte)0x28, (byte)0x3E, (byte)0x08, (byte)0x08, (byte)0x08, // Char 014 (4)
    	(byte)0x3C, (byte)0x20, (byte)0x20, (byte)0x38, (byte)0x04, (byte)0x04, (byte)0x04, (byte)0x38, // Char 015 (5)
    	(byte)0x0C, (byte)0x18, (byte)0x30, (byte)0x20, (byte)0x3C, (byte)0x24, (byte)0x24, (byte)0x3C, // Char 016 (6)
    	(byte)0x3C, (byte)0x04, (byte)0x04, (byte)0x08, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x10, // Char 017 (7)
    	(byte)0x18, (byte)0x24, (byte)0x24, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x18, // Char 018 (8)
    	(byte)0x18, (byte)0x24, (byte)0x24, (byte)0x24, (byte)0x1C, (byte)0x04, (byte)0x04, (byte)0x38, // Char 019 (9)
    	// numbers set 3
    	(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x2C, (byte)0x34, (byte)0x24, (byte)0x18, (byte)0x00, // Char 020 (0)
    	(byte)0x00, (byte)0x10, (byte)0x30, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x38, (byte)0x00, // Char 021 (1)
    	(byte)0x00, (byte)0x18, (byte)0x24, (byte)0x04, (byte)0x18, (byte)0x20, (byte)0x3C, (byte)0x00, // Char 022 (2)
    	(byte)0x00, (byte)0x38, (byte)0x04, (byte)0x18, (byte)0x04, (byte)0x04, (byte)0x38, (byte)0x00, // Char 023 (3)
    	(byte)0x60, (byte)0x60, (byte)0x6C, (byte)0x6C, (byte)0x7F, (byte)0x7F, (byte)0x0C, (byte)0x0C, // Char 024 (4)
    	(byte)0x7E, (byte)0x7C, (byte)0x60, (byte)0x7C, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x7C, // Char 025 (5)
    	(byte)0x0E, (byte)0x1C, (byte)0x38, (byte)0x70, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0x3E, // Char 026 (6)
    	(byte)0x3E, (byte)0x36, (byte)0x06, (byte)0x0C, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 027 (7)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x7E, // Char 028 (8)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x3C, // Char 029 (9)
    	// numbers set 4
    	(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x24, (byte)0x3C, (byte)0x24, (byte)0x18, (byte)0x00, // Char 030 (0)
    	(byte)0x00, (byte)0x00, (byte)0x10, (byte)0x30, (byte)0x10, (byte)0x10, (byte)0x38, (byte)0x00, // Char 031 (1)
    	(byte)0x00, (byte)0x08, (byte)0x14, (byte)0x04, (byte)0x18, (byte)0x10, (byte)0x1C, (byte)0x00, // Char 032 (2)
    	(byte)0x00, (byte)0x18, (byte)0x04, (byte)0x18, (byte)0x04, (byte)0x18, (byte)0x00, (byte)0x00, // Char 033 (3)
    	(byte)0x60, (byte)0x60, (byte)0x6C, (byte)0x6C, (byte)0x7F, (byte)0x7F, (byte)0x0C, (byte)0x0C, // Char 034 (4)
    	(byte)0x7E, (byte)0x7C, (byte)0x60, (byte)0x7C, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x7C, // Char 035 (5)
    	(byte)0x0E, (byte)0x1C, (byte)0x38, (byte)0x70, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0x3E, // Char 036 (6)
    	(byte)0x3E, (byte)0x36, (byte)0x06, (byte)0x0C, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 037 (7)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x7E, // Char 038 (8)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x3C, // Char 039 (9)
    	// numbers set 5
    	(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x24, (byte)0x24, (byte)0x18, (byte)0x00, (byte)0x00, // Char 040 (0)
    	(byte)0x00, (byte)0x00, (byte)0x10, (byte)0x30, (byte)0x10, (byte)0x38, (byte)0x00, (byte)0x00, // Char 041 (1)
    	(byte)0x00, (byte)0x00, (byte)0x1C, (byte)0x04, (byte)0x1C, (byte)0x10, (byte)0x1C, (byte)0x00, // Char 042 (2)
    	(byte)0x00, (byte)0x18, (byte)0x04, (byte)0x08, (byte)0x04, (byte)0x18, (byte)0x00, (byte)0x00, // Char 043 (3)
    	(byte)0x60, (byte)0x60, (byte)0x6C, (byte)0x6C, (byte)0x7F, (byte)0x7F, (byte)0x0C, (byte)0x0C, // Char 044 (4)
    	(byte)0x7E, (byte)0x7C, (byte)0x60, (byte)0x7C, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x7C, // Char 045 (5)
    	(byte)0x0E, (byte)0x1C, (byte)0x38, (byte)0x70, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0x3E, // Char 046 (6)
    	(byte)0x3E, (byte)0x36, (byte)0x06, (byte)0x0C, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 047 (7)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x7E, // Char 048 (8)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x3C, // Char 049 (9)
    	// numbers set 6
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, // Char 050 (0)
    	(byte)0x00, (byte)0x00, (byte)0x10, (byte)0x30, (byte)0x10, (byte)0x10, (byte)0x00, (byte)0x00, // Char 051 (1)
    	(byte)0x00, (byte)0x00, (byte)0x18, (byte)0x08, (byte)0x18, (byte)0x10, (byte)0x18, (byte)0x00, // Char 052 (2)
    	(byte)0x00, (byte)0x08, (byte)0x04, (byte)0x08, (byte)0x04, (byte)0x08, (byte)0x00, (byte)0x00, // Char 053 (3)
    	(byte)0x60, (byte)0x60, (byte)0x6C, (byte)0x6C, (byte)0x7F, (byte)0x7F, (byte)0x0C, (byte)0x0C, // Char 054 (4)
    	(byte)0x7E, (byte)0x7C, (byte)0x60, (byte)0x7C, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x7C, // Char 055 (5)
    	(byte)0x0E, (byte)0x1C, (byte)0x38, (byte)0x70, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0x3E, // Char 056 (6)
    	(byte)0x3E, (byte)0x36, (byte)0x06, (byte)0x0C, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 057 (7)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x7E, // Char 058 (8)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x3C, // Char 059 (9)
    	// numbers set 7
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, // Char 060 (0)
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x10, (byte)0x10, (byte)0x00, (byte)0x00, // Char 061 (1)
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, // Char 062 (2)
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x08, (byte)0x18, (byte)0x00, (byte)0x00, // Char 063 (3)
    	(byte)0x60, (byte)0x60, (byte)0x6C, (byte)0x6C, (byte)0x7F, (byte)0x7F, (byte)0x0C, (byte)0x0C, // Char 064 (4)
    	(byte)0x7E, (byte)0x7C, (byte)0x60, (byte)0x7C, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x7C, // Char 065 (5)
    	(byte)0x0E, (byte)0x1C, (byte)0x38, (byte)0x70, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0x3E, // Char 066 (6)
    	(byte)0x3E, (byte)0x36, (byte)0x06, (byte)0x0C, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 067 (7)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x7E, // Char 068 (8)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x3C, // Char 069 (9)
    	// numbers set 8
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x08, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, // Char 070 (0)
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x10, (byte)0x00, (byte)0x00, (byte)0x00, // Char 071 (1)
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x18, (byte)0x18, (byte)0x00, (byte)0x00, (byte)0x00, // Char 072 (2)
    	(byte)0x00, (byte)0x00, (byte)0x00, (byte)0x00, (byte)0x08, (byte)0x00, (byte)0x00, (byte)0x00, // Char 073 (3)
    	(byte)0x60, (byte)0x60, (byte)0x6C, (byte)0x6C, (byte)0x7F, (byte)0x7F, (byte)0x0C, (byte)0x0C, // Char 074 (4)
    	(byte)0x7E, (byte)0x7C, (byte)0x60, (byte)0x7C, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x7C, // Char 075 (5)
    	(byte)0x0E, (byte)0x1C, (byte)0x38, (byte)0x70, (byte)0x7C, (byte)0x66, (byte)0x66, (byte)0x3E, // Char 076 (6)
    	(byte)0x3E, (byte)0x36, (byte)0x06, (byte)0x0C, (byte)0x18, (byte)0x18, (byte)0x18, (byte)0x18, // Char 077 (7)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x7E, // Char 078 (8)
    	(byte)0x3C, (byte)0x7E, (byte)0x66, (byte)0x66, (byte)0x3E, (byte)0x06, (byte)0x3E, (byte)0x3C  // Char 079 (9)
	};
	
  public:
    int size;
    int maxBrightness;
    Point center;
    float theta, phi;
    int accelerometerX, accelerometerY, accelerometerZ;
    Cube(unsigned int s, unsigned int mb);
    Cube(void);

    void setVoxel(int x, int y, int z, Color col);
    void setVoxel(Point p, Color col);
    Color getVoxel(int x, int y, int z);
    Color getVoxel(Point p);
    void line(int x1, int y1, int z1, int x2, int y2, int z2, Color col);
    void line(Point p1, Point p2, Color col);
    void sphere(int x, int y, int z, int r, Color col);
    void sphere(Point p, int r, Color col);
    void shell(float x, float y, float z, float r, Color col);
    void shell(float x, float y, float z, float r, float thickness, Color col);
    void shell(Point p, float r, Color col);
    void shell(Point p, float r, float thickness, Color col);
    void emptyFlatCircle(int x, int y, int z, int r, Color col);
    void updateAccelerometer();
    void background(Color col);

    Color colorMap(float val, float min, float max);
    Color lerpColor(Color a, Color b, int val, int min, int max);

    void begin(void);
    void show(void);
    void listen(void);
    void initButtons(void);
    void onlineOfflineSwitch(void);
    void joinWifi(void);
    void updateNetworkInfo(void);
    int setPort(String port);

	// Text members
	int selectedFont;
	bool looping;
	bool done;
	void showChar(char a, Point p, Color col);
	void showChar(char a, Point origin, Point angle, Color col);
	void showChar(char a, Point origin, Point pivot, Point angle, Color col);
	void scrollSpinningText(std::string text, Point initialPosition, Color col);
	void scrollText(std::string text, Point initialPosition, Color col);
	void marquee(std::string text, float pos, Color col);
	void showMarqueeChar(char a, int pos, Color col);
};

// Text fonts
enum FontType {
    SKINNY_FONT = 0,
    CUBE_FONT   = 256
};

// common colors
const Color black     = Color(0x00, 0x00, 0x00);
const Color grey      = Color(0x92, 0x95, 0x91);
const Color yellow    = Color(0xff, 0xff, 0x14);
const Color magenta   = Color(0xc2, 0x00, 0x78);
const Color orange    = Color(0xf9, 0x73, 0x06);
const Color teal      = Color(0x02, 0x93, 0x86);
const Color red       = Color(0xe5, 0x00, 0x00);
const Color brown     = Color(0x65, 0x37, 0x00);
const Color pink      = Color(0xff, 0x81, 0xc0);
const Color blue      = Color(0x03, 0x43, 0xdf);
const Color green     = Color(0x15, 0xb0, 0x1a);
const Color purple    = Color(0x7e, 0x1e, 0x9c);
const Color white     = Color(0xff, 0xff, 0xff);

#endif